@@ -82,6 +82,8 @@ class User(Base):
     site_admin           = Column(Boolean(create_constraint=False), nullable=False)
     group_admin          = Column(Boolean(create_constraint=False), nullable=False)
     site_read            = Column(Boolean(create_constraint=False), nullable=False)
+    tfa_secret           = Column(Text)
+
     # Relationships
     group                = relationship('Group', back_populates='user')
     metadatasets         = relationship('MetaDataSet', back_populates='user')
@@ -90,6 +92,19 @@ class User(Base):
     apikeys              = relationship('ApiKey', back_populates='user')
     services             = relationship('Service', secondary=user_service_table, back_populates='users')
     service_executions   = relationship('ServiceExecution', back_populates='user')
+    tfatokens            = relationship('TfaToken', back_populates='user')
+    used_passwords       = relationship('UsedPassword', back_populates='user')
+    login_attempts       = relationship("LoginAttempt", back_populates='user', cascade="all, delete-orphan")
+
+
+class LoginAttempt(Base):
+    __tablename__    = 'loginattempts'
+    id               = Column(Integer, primary_key=True)
+    uuid             = Column(UUID(as_uuid=True), unique=True, default=uuid.uuid4, nullable=False)
+    user_id          = Column(Integer, ForeignKey('users.id'), nullable=False)
+    timestamp        = Column(DateTime, nullable=False)
+    # Relationships
+    user             = relationship('User', back_populates='login_attempts')
 
 
 class ApiKey(Base):
@@ -115,6 +130,29 @@ class PasswordToken(Base):
     user             = relationship('User', back_populates='passwordtokens')
 
 
+class TfaToken(Base):
+    __tablename__ = 'tfatokens'
+    id            = Column(Integer, primary_key=True)
+    uuid          = Column(UUID(as_uuid=True), unique=True, default=uuid.uuid4, nullable=False)
+    user_id       = Column(Integer, ForeignKey('users.id'), nullable=False)
+    value         = Column(Text, nullable=False, unique=True)
+    expires       = Column(DateTime, nullable=False)
+    secret        = Column(Text, default=None)
+    # Relationships
+    user          = relationship('User', back_populates='tfatokens')
+
+
+class UsedPassword(Base):
+    __tablename__ = 'usedpasswords'
+    id            = Column(Integer, primary_key=True)
+    uuid          = Column(UUID(as_uuid=True), unique=True, default=uuid.uuid4, nullable=False)
+    user_id       = Column(Integer, ForeignKey('users.id'), nullable=False)
+    pwhash        = Column(Text, nullable=False, unique=True)
+
+    # Relationships
+    user          = relationship('User', back_populates='used_passwords')
+
+
 class RegRequest(Base):
     __tablename__    = 'regrequests'
     id               = Column(Integer, primary_key=True)
